summaryrefslogtreecommitdiffstats
path: root/src/usr
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2013-08-20 16:28:44 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-09-12 14:07:44 -0500
commit24f7b770b42f2889e8970e75f1ecd8bc1bdb77d5 (patch)
tree942e1dbbf85a21b215238805ed600794df5f4764 /src/usr
parentd8fdb9f6399d602c3314fe8a0a6578364e886120 (diff)
downloadtalos-hostboot-24f7b770b42f2889e8970e75f1ecd8bc1bdb77d5.tar.gz
talos-hostboot-24f7b770b42f2889e8970e75f1ecd8bc1bdb77d5.zip
GARD: errlog event ID (EID) instead of platform log id (PLID)
gard records and deconfiguredBy use event id instead of plid. Change-Id: Ic0ccbd5b83e1738839819d471956ca700cd22fff RTC: 79346 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/5853 Tested-by: Jenkins Server Reviewed-by: SHELDON R. BAILEY <baileysh@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr')
-rw-r--r--src/usr/hwas/common/deconfigGard.C96
-rw-r--r--src/usr/hwas/common/hwas.C39
-rw-r--r--src/usr/hwas/common/hwasCallout.C3
-rw-r--r--src/usr/hwas/hwasPlatCallout.C4
-rw-r--r--src/usr/hwas/hwasPlatDeconfigGard.C14
-rw-r--r--src/usr/hwas/test/hwas1test.H8
-rw-r--r--src/usr/hwas/test/hwasGardTest.H4
-rw-r--r--src/usr/hwas/test/hwasSysAvailSvcTest.H2
-rw-r--r--src/usr/targeting/common/xmltohb/attribute_types.xml4
9 files changed, 84 insertions, 90 deletions
diff --git a/src/usr/hwas/common/hwasCallout.C b/src/usr/hwas/common/hwasCallout.C
index a307643e0..1d226f20f 100644
--- a/src/usr/hwas/common/hwasCallout.C
+++ b/src/usr/hwas/common/hwasCallout.C
@@ -117,8 +117,7 @@ void processCallout(errlHndl_t &io_errl,
if (!l_err)
{
HWAS::theDeconfigGard().registerDeferredDeconfigure(
- *pTarget,
- io_errl->plid());
+ *pTarget, io_errl->eid());
}
}
// else, no deferred deconfigures - all good.
diff --git a/src/usr/hwas/hwasPlatCallout.C b/src/usr/hwas/hwasPlatCallout.C
index 6a9127d7f..52a5d2b5e 100644
--- a/src/usr/hwas/hwasPlatCallout.C
+++ b/src/usr/hwas/hwasPlatCallout.C
@@ -90,7 +90,7 @@ errlHndl_t platHandleHWCallout(
default:
{
errl = HWAS::theDeconfigGard().createGardRecord(i_pTarget,
- io_errl->plid(),
+ io_errl->eid(),
i_gardErrorType);
break;
}
@@ -106,7 +106,7 @@ errlHndl_t platHandleHWCallout(
{
// call HWAS common function
errl = HWAS::theDeconfigGard().deconfigureTarget(*i_pTarget,
- io_errl->plid());
+ io_errl->eid());
break;
}
case (DELAYED_DECONFIG):
diff --git a/src/usr/hwas/test/hwas1test.H b/src/usr/hwas/test/hwas1test.H
index ba6829fd7..151ef6c2a 100644
--- a/src/usr/hwas/test/hwas1test.H
+++ b/src/usr/hwas/test/hwas1test.H
@@ -77,7 +77,7 @@ public:
// modify state
l_hwasState = l_pTarget->getAttr<ATTR_HWAS_STATE>();
- l_hwasState.deconfiguredByPlid = 0x12345678;
+ l_hwasState.deconfiguredByEid = 0x12345678;
l_hwasState.poweredOn = true;
l_hwasState.present = true;
l_hwasState.functional = true;
@@ -86,12 +86,12 @@ public:
l_pTarget->setAttr<ATTR_HWAS_STATE>( l_hwasState );
// fetch and test new values
- if ( l_pTarget->getAttr<ATTR_HWAS_STATE>().deconfiguredByPlid
+ if ( l_pTarget->getAttr<ATTR_HWAS_STATE>().deconfiguredByEid
!= 0x12345678 )
{
- TS_FAIL( " deconfiguredByPlid = 0x%x, should be 0x12345678",
+ TS_FAIL( " deconfiguredByEid = 0x%x, should be 0x12345678",
l_pTarget->getAttr<ATTR_HWAS_STATE>().
- deconfiguredByPlid );
+ deconfiguredByEid );
}
if ( l_pTarget->getAttr<ATTR_HWAS_STATE>().poweredOn != true )
diff --git a/src/usr/hwas/test/hwasGardTest.H b/src/usr/hwas/test/hwasGardTest.H
index 6a217149f..991982c22 100644
--- a/src/usr/hwas/test/hwasGardTest.H
+++ b/src/usr/hwas/test/hwasGardTest.H
@@ -1120,11 +1120,11 @@ public:
break;
}
- if ((l_records[0].iv_errlogPlid != 0x46) ||
+ if ((l_records[0].iv_errlogEid != 0x46) ||
(l_records[0].iv_errorType != GARD_Fatal))
{
TS_FAIL("testGard6: unexpected data - errl 0x%X type %x",
- l_records[0].iv_errlogPlid, l_records[0].iv_errorType);
+ l_records[0].iv_errlogEid, l_records[0].iv_errorType);
break;
}
diff --git a/src/usr/hwas/test/hwasSysAvailSvcTest.H b/src/usr/hwas/test/hwasSysAvailSvcTest.H
index 3039c0ef6..0e5839ce2 100644
--- a/src/usr/hwas/test/hwasSysAvailSvcTest.H
+++ b/src/usr/hwas/test/hwasSysAvailSvcTest.H
@@ -96,7 +96,7 @@ public:
l_fakeState = i_origStates[i];
TS_TRACE( "setTargetStates: HwasState fakeState: "
"deconf=0x%x,PO=0x%x,pres=0x%x,func=0x%x,dumpf=0x%x",
- l_fakeState.deconfiguredByPlid,
+ l_fakeState.deconfiguredByEid,
l_fakeState.poweredOn,
l_fakeState.present,
l_fakeState.functional,
diff --git a/src/usr/targeting/common/xmltohb/attribute_types.xml b/src/usr/targeting/common/xmltohb/attribute_types.xml
index 2573a3de9..258d7260e 100644
--- a/src/usr/targeting/common/xmltohb/attribute_types.xml
+++ b/src/usr/targeting/common/xmltohb/attribute_types.xml
@@ -783,10 +783,10 @@
<complexType>
<description>struct - 4 booleans and a PLID</description>
<field>
- <name>deconfiguredByPlid</name>
+ <name>deconfiguredByEid</name>
<description>if this target was deconfigured,
this will be a special DECONFIGURED_BY_ enum,
- OR it will be the errlog PLID that caused it,
+ OR it will be the errlog EID that caused it,
either directly or by association,
</description>
<type>uint32_t</type>
OpenPOWER on IntegriCloud
diff --git a/src/usr/hwas/common/deconfigGard.C b/src/usr/hwas/common/deconfigGard.C
index f271237e6..64198d5bb 100644
--- a/src/usr/hwas/common/deconfigGard.C
+++ b/src/usr/hwas/common/deconfigGard.C
@@ -302,10 +302,10 @@ errlHndl_t DeconfigGard::deconfigureTargetsFromGardRecordsForIpl(
continue;
}
- // special case - use errlogPlid UNLESS it's a Manual Gard
- const uint32_t l_errlogPlid =
+ // special case - use errlogEid UNLESS it's a Manual Gard
+ const uint32_t l_errlogEid =
(l_gardRecord.iv_errorType == GARD_User_Manual) ?
- DECONFIGURED_BY_MANUAL_GARD : l_gardRecord.iv_errlogPlid;
+ DECONFIGURED_BY_MANUAL_GARD : l_gardRecord.iv_errlogEid;
// all ok - do the work
HWAS_MUTEX_LOCK(iv_mutex);
@@ -313,10 +313,10 @@ errlHndl_t DeconfigGard::deconfigureTargetsFromGardRecordsForIpl(
// Deconfigure the Target
// don't need to check ATTR_DECONFIG_GARDABLE -- if we get
// here, it's because of a gard record on this target
- _deconfigureTarget(*l_pTarget, l_errlogPlid);
+ _deconfigureTarget(*l_pTarget, l_errlogEid);
// Deconfigure other Targets by association
- _deconfigureByAssoc(*l_pTarget, l_errlogPlid);
+ _deconfigureByAssoc(*l_pTarget, l_errlogEid);
HWAS_MUTEX_UNLOCK(iv_mutex);
} // for
@@ -449,7 +449,7 @@ errlHndl_t DeconfigGard::processFieldCoreOverride()
//******************************************************************************
errlHndl_t DeconfigGard::createGardRecord(const Target * const i_pTarget,
- const uint32_t i_errlPlid,
+ const uint32_t i_errlEid,
const GARD_ErrorType i_errorType)
{
errlHndl_t l_pErr = NULL;
@@ -472,12 +472,11 @@ errlHndl_t DeconfigGard::createGardRecord(const Target * const i_pTarget,
* @devdesc Attempt to create a GARD Record for a target that
* is not GARDable
* (not DECONFIG_GARDABLE or not present)
* @userdata1 HUID of input target // GARD errlog PLID
* @userdata2 ATTR_DECONFIG_GARDABLE // ATTR_HWAS_STATE.present
*/
const uint64_t userdata1 =
- (static_cast<uint64_t>(get_huid(i_pTarget)) << 32) |
- i_errlPlid;
+ (static_cast<uint64_t>(get_huid(i_pTarget)) << 32) | i_errlEid;
const uint64_t userdata2 =
(static_cast<uint64_t>(lDeconfigGardable) << 32) | lPresent;
l_pErr = hwasError(
@@ -522,7 +521,7 @@ errlHndl_t DeconfigGard::createGardRecord(const Target * const i_pTarget,
break;
}
- l_pErr = platCreateGardRecord(i_pTarget, i_errlPlid, i_errorType);
+ l_pErr = platCreateGardRecord(i_pTarget, i_errlEid, i_errorType);
}
while (0);
@@ -548,7 +547,7 @@ errlHndl_t DeconfigGard::getGardRecords(
//******************************************************************************
errlHndl_t DeconfigGard::deconfigureTarget(Target & i_target,
- const uint32_t i_errlPlid,
+ const uint32_t i_errlEid,
bool i_evenAtRunTime)
{
HWAS_INF("Deconfigure Target");
@@ -581,12 +580,11 @@ errlHndl_t DeconfigGard::deconfigureTarget(Target & i_target,
* @devdesc Attempt to deconfigure a target that is not
* deconfigurable
* (not DECONFIG_GARDABLE or not present)
* @userdata1 HUID of input target // GARD errlog PLID
* @userdata2 ATTR_DECONFIG_GARDABLE // ATTR_HWAS_STATE.present
*/
const uint64_t userdata1 =
- (static_cast<uint64_t>(get_huid(&i_target)) << 32) |
- i_errlPlid;
+ (static_cast<uint64_t>(get_huid(&i_target)) << 32) | i_errlEid;
const uint64_t userdata2 =
(static_cast<uint64_t>(lDeconfigGardable) << 32) | lPresent;
l_pErr = hwasError(
@@ -602,10 +600,10 @@ errlHndl_t DeconfigGard::deconfigureTarget(Target & i_target,
HWAS_MUTEX_LOCK(iv_mutex);
// Deconfigure the Target
- _deconfigureTarget(i_target, i_errlPlid);
+ _deconfigureTarget(i_target, i_errlEid);
// Deconfigure other Targets by association
- _deconfigureByAssoc(i_target, i_errlPlid);
+ _deconfigureByAssoc(i_target, i_errlEid);
HWAS_MUTEX_UNLOCK(iv_mutex);
@@ -625,14 +623,14 @@ errlHndl_t DeconfigGard::deconfigureTarget(Target & i_target,
//******************************************************************************
void DeconfigGard::registerDeferredDeconfigure(
const Target & i_target,
- const uint32_t i_errlPlid)
+ const uint32_t i_errlEid)
{
- HWAS_INF("registerDeferredDeconfigure Target %.8X, errlPlid 0x%X",
- get_huid(&i_target), i_errlPlid);
+ HWAS_INF("registerDeferredDeconfigure Target %.8X, errlEid 0x%X",
+ get_huid(&i_target), i_errlEid);
// Create a Deconfigure Record
HWAS_MUTEX_LOCK(iv_mutex);
- _createDeconfigureRecord(i_target, i_errlPlid);
+ _createDeconfigureRecord(i_target, i_errlEid);
HWAS_MUTEX_UNLOCK(iv_mutex);
}
@@ -769,7 +767,7 @@ void findMcsInGroup(const Target *i_startMcs, TargetHandleList &o_McsInGroup)
//******************************************************************************
void DeconfigGard::_deconfigureByAssoc(Target & i_target,
- const uint32_t i_errlPlid)
+ const uint32_t i_errlEid)
{
HWAS_INF("deconfigByAssoc for %.8X", get_huid(&i_target));
@@ -790,9 +788,9 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
TargetHandle_t pChild = *pChild_it;
HWAS_INF("deconfigByAssoc CHILD: %.8X", get_huid(pChild));
- _deconfigureTarget(*pChild, i_errlPlid);
+ _deconfigureTarget(*pChild, i_errlEid);
// Deconfigure other Targets by association
- _deconfigureByAssoc(*pChild, i_errlPlid);
+ _deconfigureByAssoc(*pChild, i_errlEid);
} // for CHILD
// find all CHILD_BY_AFFINITY matches for this target and deconfigure them
@@ -805,9 +803,9 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
TargetHandle_t pChild = *pChild_it;
HWAS_INF("deconfigByAssoc CHILD_BY_AFFINITY: %.8X", get_huid(pChild));
- _deconfigureTarget(*pChild, i_errlPlid);
+ _deconfigureTarget(*pChild, i_errlEid);
// Deconfigure other Targets by association
- _deconfigureByAssoc(*pChild, i_errlPlid);
+ _deconfigureByAssoc(*pChild, i_errlEid);
} // for CHILD_BY_AFFINITY
// Memory deconfigureByAssociation rules
@@ -834,9 +832,9 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
HWAS_INF("deconfigByAssoc MEMBUF parent MCS: %.8X",
get_huid(l_parentMcs));
_deconfigureTarget(const_cast<Target &> (*l_parentMcs),
- i_errlPlid);
+ i_errlEid);
_deconfigureByAssoc(const_cast<Target &> (*l_parentMcs),
- i_errlPlid);
+ i_errlEid);
Target *pSys;
targetService().getTopLevelTarget(pSys);
@@ -863,8 +861,8 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
HWAS_INF("deconfigByAssoc MCS (& MEMBUF) paired: %.8X",
get_huid(pMcs));
- _deconfigureTarget(*pMcs, i_errlPlid);
- _deconfigureByAssoc(*pMcs, i_errlPlid);
+ _deconfigureTarget(*pMcs, i_errlEid);
+ _deconfigureByAssoc(*pMcs, i_errlEid);
} // for
break;
} // TYPE_MEMBUF
@@ -890,9 +888,9 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
HWAS_INF("deconfigByAssoc MEMBUF parent with no memory: %.8X",
get_huid(l_parentMembuf));
_deconfigureTarget(const_cast<Target &> (*l_parentMembuf),
- i_errlPlid);
+ i_errlEid);
_deconfigureByAssoc(const_cast<Target &> (*l_parentMembuf),
- i_errlPlid);
+ i_errlEid);
// and we're done, so break;
break;
@@ -995,7 +993,7 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
{
HWAS_INF("deconfigByAssoc MBA matched: %.8X",
get_huid(pMba));
- _deconfigureTarget(*pMba, i_errlPlid);
+ _deconfigureTarget(*pMba, i_errlEid);
l_deconfigList.push_back(pMba);
break; // only need to do 1 MBA - we're done.
}
@@ -1015,7 +1013,7 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
TargetHandle_t pMba = *pMba_it;
HWAS_INF("deconfigByAssoc MBA matched (bA): %.8X",
get_huid(pMba));
- _deconfigureByAssoc(*pMba, i_errlPlid);
+ _deconfigureByAssoc(*pMba, i_errlEid);
} // for
break;
} // TYPE_MBA
@@ -1036,9 +1034,9 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
HWAS_INF("deconfigByAssoc DIMM parent MBA: %.8X",
get_huid(l_parentMba));
_deconfigureTarget(const_cast<Target &> (*l_parentMba),
- i_errlPlid);
+ i_errlEid);
_deconfigureByAssoc(const_cast<Target &> (*l_parentMba),
- i_errlPlid);
+ i_errlEid);
}
break;
} // TYPE_DIMM
@@ -1052,10 +1050,10 @@ void DeconfigGard::_deconfigureByAssoc(Target & i_target,
//******************************************************************************
void DeconfigGard::_deconfigureTarget(Target & i_target,
- const uint32_t i_errlPlid)
+ const uint32_t i_errlEid)
{
- HWAS_INF("Deconfiguring Target %.8X, errlPlid 0x%X",
- get_huid(&i_target), i_errlPlid);
+ HWAS_INF("Deconfiguring Target %.8X, errlEid 0x%X",
+ get_huid(&i_target), i_errlEid);
// Set the Target state to non-functional. The assumption is that it is
// not possible for another thread (other than deconfigGard) to be
@@ -1066,16 +1064,16 @@ void DeconfigGard::_deconfigureTarget(Target & i_target,
if (!l_state.functional)
{
HWAS_DBG(
- "Target HWAS_STATE already has functional=0; deconfiguredByPlid=0x%X",
- l_state.deconfiguredByPlid);
+ "Target HWAS_STATE already has functional=0; deconfiguredByEid=0x%X",
+ l_state.deconfiguredByEid);
}
else
{
HWAS_INF(
- "Setting Target HWAS_STATE: functional=0, deconfiguredByPlid=0x%X",
- i_errlPlid);
+ "Setting Target HWAS_STATE: functional=0, deconfiguredByEid=0x%X",
+ i_errlEid);
l_state.functional = 0;
- l_state.deconfiguredByPlid = i_errlPlid;
+ l_state.deconfiguredByEid = i_errlEid;
i_target.setAttr<ATTR_HWAS_STATE>(l_state);
// Do any necessary Deconfigure Actions
@@ -1094,7 +1092,7 @@ void DeconfigGard::_doDeconfigureActions(Target & i_target)
//******************************************************************************
void DeconfigGard::_createDeconfigureRecord(
const Target & i_target,
- const uint32_t i_errlPlid)
+ const uint32_t i_errlEid)
{
// Look for an existing Deconfigure Record for the Target
DeconfigureRecordsCItr_t l_itr = iv_deconfigureRecords.begin();
@@ -1103,8 +1101,8 @@ void DeconfigGard::_createDeconfigureRecord(
{
if ((*l_itr).iv_target == &i_target)
{
- HWAS_DBG("Not creating Deconfigure Record, one exists errlPlid 0x%X",
- (*l_itr).iv_errlogPlid);
+ HWAS_DBG("Not creating Deconfigure Record, one exists errlEid 0x%X",
+ (*l_itr).iv_errlogEid);
break;
}
}
@@ -1117,7 +1115,7 @@ void DeconfigGard::_createDeconfigureRecord(
DeconfigureRecord l_record;
l_record.iv_target = &i_target;
- l_record.iv_errlogPlid = i_errlPlid;
+ l_record.iv_errlogEid = i_errlEid;
iv_deconfigureRecords.push_back(l_record);
}
@@ -1179,9 +1177,9 @@ bool DeconfigGard::_processDeferredDeconfig()
// do the deconfigure
DeconfigureRecord l_record = *l_itr;
_deconfigureTarget(const_cast<Target &> (*(l_record.iv_target)),
- l_record.iv_errlogPlid);
+ l_record.iv_errlogEid);
_deconfigureByAssoc(const_cast<Target &> (*(l_record.iv_target)),
- l_record.iv_errlogPlid);
+ l_record.iv_errlogEid);
} // for
// clear the list - handled them all
@@ -472,12 +472,11 @@ errlHndl_t DeconfigGard::createGardRecord(const Target * const i_pTarget,
* is not GARDable
* (not DECONFIG_GARDABLE or not present)
- * @userdata1 HUID of input target // GARD errlog PLID
+ * @userdata1 HUID of input target // GARD errlog EID
* @userdata2 ATTR_DECONFIG_GARDABLE // ATTR_HWAS_STATE.present
*/
@@ -581,12 +580,11 @@ errlHndl_t DeconfigGard::deconfigureTarget(Target & i_target,
* deconfigurable
* (not DECONFIG_GARDABLE or not present)
- * @userdata1 HUID of input target // GARD errlog PLID
+ * @userdata1 HUID of input target // GARD errlog EID
* @userdata2 ATTR_DECONFIG_GARDABLE // ATTR_HWAS_STATE.present
*/
diff --git a/src/usr/hwas/common/hwas.C b/src/usr/hwas/common/hwas.C
index cf0bc6185..fc6017e66 100644
--- a/src/usr/hwas/common/hwas.C
+++ b/src/usr/hwas/common/hwas.C
@@ -86,7 +86,7 @@ bool compareProcGroup(procRestrict_t t1, procRestrict_t t2)
* @param[in] i_target pointer to target that we're looking at
* @param[in] i_present boolean indicating present or not
* @param[in] i_functional boolean indicating functional or not
- * @param[in] i_errlPlid errplid that caused change to non-funcational;
+ * @param[in] i_errlEid erreid that caused change to non-funcational;
* 0 if not associated with an error or if
* functional is true
*
@@ -95,13 +95,13 @@ bool compareProcGroup(procRestrict_t t1, procRestrict_t t2)
*/
void enableHwasState(Target *i_target,
bool i_present, bool i_functional,
- uint32_t i_errlPlid)
+ uint32_t i_errlEid)
{
HwasState hwasState = i_target->getAttr<ATTR_HWAS_STATE>();
if (i_functional == false)
- { // record the PLID as a reason that we're marking non-functional
- hwasState.deconfiguredByPlid = i_errlPlid;
+ { // record the EID as a reason that we're marking non-functional
+ hwasState.deconfiguredByEid = i_errlEid;
}
hwasState.poweredOn = true;
hwasState.present = i_present;
@@ -121,7 +121,7 @@ errlHndl_t discoverTargets()
++target)
{
HwasState hwasState = target->getAttr<ATTR_HWAS_STATE>();
- hwasState.deconfiguredByPlid = 0;
+ hwasState.deconfiguredByEid = 0;
hwasState.poweredOn = false;
hwasState.present = false;
hwasState.functional = false;
@@ -202,7 +202,7 @@ errlHndl_t discoverTargets()
bool chipPresent = true;
bool chipFunctional = true;
- uint32_t errlPlid = 0;
+ uint32_t errlEid = 0;
uint16_t pgData[VPD_CP00_PG_DATA_LENGTH / sizeof(uint16_t)];
bzero(pgData, sizeof(pgData));
@@ -213,10 +213,10 @@ errlHndl_t discoverTargets()
if (errl)
{ // read of ID/EC failed even tho we were present..
- HWAS_INF("pTarget %.8X - read IDEC failed (plid 0x%X) - bad",
- errl->plid(), pTarget->getAttr<ATTR_HUID>());
+ HWAS_INF("pTarget %.8X - read IDEC failed (eid 0x%X) - bad",
+ errl->eid(), pTarget->getAttr<ATTR_HUID>());
chipFunctional = false;
- errlPlid = errl->plid();
+ errlEid = errl->eid();
// commit the error but keep going
errlCommit(errl, HWAS_COMP_ID);
@@ -229,10 +229,10 @@ errlHndl_t discoverTargets()
if (errl)
{ // read of PG failed even tho we were present..
- HWAS_INF("pTarget %.8X - read PG failed (plid 0x%X)- bad",
- errl->plid(), pTarget->getAttr<ATTR_HUID>());
+ HWAS_INF("pTarget %.8X - read PG failed (eid 0x%X)- bad",
+ errl->eid(), pTarget->getAttr<ATTR_HUID>());
chipFunctional = false;
- errlPlid = errl->plid();
+ errlEid = errl->eid();
// commit the error but keep going
errlCommit(errl, HWAS_COMP_ID);
@@ -283,7 +283,7 @@ errlHndl_t discoverTargets()
HWAS_INF("pTarget %.8X - read PR failed - bad",
pTarget->getAttr<ATTR_HUID>());
chipFunctional = false;
- errlPlid = errl->plid();
+ errlEid = errl->eid();
// commit the error but keep going
errlCommit(errl, HWAS_COMP_ID);
@@ -411,7 +411,7 @@ errlHndl_t discoverTargets()
// for sub-parts, if it's not functional, it's not present.
enableHwasState(pDesc, descFunctional, descFunctional,
- errlPlid);
+ errlEid);
HWAS_DBG("pDesc %.8X - marked %spresent, %sfunctional",
pDesc->getAttr<ATTR_HUID>(),
descFunctional ? "" : "NOT ",
@@ -419,7 +419,7 @@ errlHndl_t discoverTargets()
}
// set HWAS state to show CHIP is present, functional per above
- enableHwasState(pTarget, chipPresent, chipFunctional, errlPlid);
+ enableHwasState(pTarget, chipPresent, chipFunctional, errlEid);
} // for pTarget_it
@@ -689,8 +689,7 @@ errlHndl_t checkMinimumHardware()
SRCI_PRIORITY_HIGH );
// if we already have an error, link this one to the earlier plid.
// if not, set the common plid
- hwasErrorUpdatePlid( l_errl,
- l_commonPlid );
+ hwasErrorUpdatePlid( l_errl, l_commonPlid );
// finally, commit the log.
errlCommit(l_errl, HWAS_COMP_ID);
@@ -731,8 +730,7 @@ errlHndl_t checkMinimumHardware()
SRCI_PRIORITY_HIGH );
// if we already have an error, link this one to the earlier plid.
// if not, set the common plid
- hwasErrorUpdatePlid( l_errl,
- l_commonPlid );
+ hwasErrorUpdatePlid( l_errl, l_commonPlid );
errlCommit(l_errl, HWAS_COMP_ID);
// errl is now NULL
@@ -777,8 +775,7 @@ errlHndl_t checkMinimumHardware()
EPUB_PRC_FIND_DECONFIGURED_PART,
SRCI_PRIORITY_HIGH );
// if we already have an error, link this one to the earlier plid.
- hwasErrorUpdatePlid( l_errl,
- l_commonPlid );
+ hwasErrorUpdatePlid( l_errl, l_commonPlid );
}
}
while (0);
diff --git a/src/usr/hwas/hwasPlatDeconfigGard.C b/src/usr/hwas/hwasPlatDeconfigGard.C
index e8187743e..71ffb2d78 100644
--- a/src/usr/hwas/hwasPlatDeconfigGard.C
+++ b/src/usr/hwas/hwasPlatDeconfigGard.C
@@ -177,11 +177,11 @@ errlHndl_t DeconfigGard::platGetGardRecords(
errlHndl_t DeconfigGard::platCreateGardRecord(
const Target * const i_pTarget,
- const uint32_t i_errlPlid,
+ const uint32_t i_errlEid,
const GARD_ErrorType i_errorType)
{
HWAS_INF("Creating GARD Record for %.8X, errl 0x%X",
- get_huid(i_pTarget), i_errlPlid);
+ get_huid(i_pTarget), i_errlEid);
errlHndl_t l_pErr = NULL;
HWAS_MUTEX_LOCK(iv_mutex);
@@ -222,7 +222,7 @@ errlHndl_t DeconfigGard::platCreateGardRecord(
l_duplicate = true;
l_pRecord = &(l_pGardRecords[i]);
HWAS_INF("Duplicate GARD Record from error 0x%X",
- l_pGardRecords[i].iv_errlogPlid);
+ l_pGardRecords[i].iv_errlogEid);
break;
}
}
@@ -237,7 +237,7 @@ errlHndl_t DeconfigGard::platCreateGardRecord(
if (l_pRecord->iv_errorType == GARD_User_Manual)
{
HWAS_INF("Duplicate is GARD_User_Manual - overwriting");
- l_pRecord->iv_errlogPlid = i_errlPlid;
+ l_pRecord->iv_errlogEid = i_errlEid;
l_pRecord->iv_errorType = i_errorType;
_flush((void *)l_pRecord);
}
@@ -256,11 +256,11 @@ errlHndl_t DeconfigGard::platCreateGardRecord(
* @reasoncode HWAS::RC_GARD_REPOSITORY_FULL
* @devdesc Attempt to create a GARD Record and the GARD
* Repository is full
* @userdata1 HUID of input target // GARD errlog PLID
*/
const uint64_t userdata1 =
(static_cast<uint64_t> (get_huid(i_pTarget)) << 32) |
- i_errlPlid;
+ i_errlEid;
l_pErr = hwasError(
ERRL_SEV_UNRECOVERABLE,
HWAS::MOD_DECONFIG_GARD,
@@ -271,7 +271,7 @@ errlHndl_t DeconfigGard::platCreateGardRecord(
l_pRecord->iv_recordId = l_hbDeconfigGard->iv_nextGardRecordId++;
l_pRecord->iv_targetId = l_targetId;
- l_pRecord->iv_errlogPlid = i_errlPlid;
+ l_pRecord->iv_errlogEid = i_errlEid;
l_pRecord->iv_errorType = i_errorType;
l_pRecord->iv_padding[0] = 0;
l_pRecord->iv_padding[1] = 0;
@@ -256,11 +256,11 @@ errlHndl_t DeconfigGard::platCreateGardRecord(
* @devdesc Attempt to create a GARD Record and the GARD
* Repository is full
- * @userdata1 HUID of input target // GARD errlog PLID
+ * @userdata1 HUID of input target // GARD errlog EID
*/
const uint64_t userdata1 =